@@ -5,7 +5,13 @@ from pylops.LinearOperator import aslinearoperator
 
 
 def Laplacian(
-    dims, dirs=(0, 1), weights=(1, 1), sampling=(1, 1), edge=False, dtype="float64"
+    dims,
+    dirs=(0, 1),
+    weights=(1, 1),
+    sampling=(1, 1),
+    edge=False,
+    dtype="float64",
+    kind="centered",
 ):
     r"""Laplacian.
 
@@ -27,15 +33,22 @@ def Laplacian(
         Sampling steps for each direction
     edge : :obj:`bool`, optional
         Use reduced order derivative at edges (``True``) or
-        ignore them (``False``)
+        ignore them (``False``) for centered derivative
     dtype : :obj:`str`, optional
         Type of elements in input array.
+    kind : :obj:`str`, optional
+        Derivative kind (``forward``, ``centered``, or ``backward``)
 
     Returns
     -------
     l2op : :obj:`pylops.LinearOperator`
         Laplacian linear operator
 
+    Raises
+    ------
+    ValueError
+        If ``dirs``. ``weights``, and ``sampling`` do not have the same size
+
     Notes
     -----
     The Laplacian operator applies a second derivative along two directions of
@@ -48,20 +61,27 @@ def Laplacian(
                   / (\Delta x \Delta y)
 
     """
+    if not (len(dirs) == len(weights) == len(sampling)):
+        raise ValueError("dirs, weights, and sampling have different size")
+
     l2op = weights[0] * SecondDerivative(
         np.prod(dims),
         dims=dims,
         dir=dirs[0],
         sampling=sampling[0],
         edge=edge,
+        kind=kind,
         dtype=dtype,
     )
-    l2op += weights[1] * SecondDerivative(
-        np.prod(dims),
-        dims=dims,
-        dir=dirs[1],
-        sampling=sampling[1],
-        edge=edge,
-        dtype=dtype,
-    )
+    
+    for dir, samp, weight in zip(dirs[1:], sampling[1:], weights[1:]):
+        l2op += weight * SecondDerivative(
+            np.prod(dims),
+            dims=dims,
+            dir=dir,
+            sampling=samp,
+            edge=edge,
+            dtype=dtype,
+        )
+    
     return aslinearoperator(l2op)
