@@ -1,4 +1,5 @@
 import numpy as np
+
 from pylops import LinearOperator
 from pylops.utils.backend import get_array_module
 
@@ -42,7 +43,8 @@ class Zero(LinearOperator):
        \mathbf{0} \mathbf{y} = \mathbf{0}_M
 
     """
-    def __init__(self, N, M=None, dtype='float64'):
+
+    def __init__(self, N, M=None, dtype="float64"):
         M = N if M is None else M
         self.shape = (N, M)
         self.dtype = np.dtype(dtype)
